.. _api_reference:

API Reference
=============

This section provides a detailed reference for the SuperPandas API.

SuperDataFrame (`superpandas.superdataframe`)
---------------------------------------------

.. automodule:: superpandas.superdataframe

.. autoclass:: superpandas.superdataframe.SuperDataFrameAccessor
   :members:
   :undoc-members:

.. autofunction:: superpandas.superdataframe.create_super_dataframe
.. autofunction:: superpandas.superdataframe.read_csv
.. autofunction:: superpandas.superdataframe.read_pickle


LLM Client (`superpandas.llm_client`)
--------------------------------------

.. automodule:: superpandas.llm_client

.. autoclass:: superpandas.llm_client.LLMClient
   :members:
   :undoc-members:

.. autoclass:: superpandas.llm_client.LLMMessage
   :members:
   :undoc-members:

.. autoclass:: superpandas.llm_client.LLMResponse
   :members:
   :undoc-members:

Configuration (`superpandas.config`)
------------------------------------

.. automodule:: superpandas.config

.. autoclass:: superpandas.config.SuperPandasConfig
   :members:
   :undoc-members:
